KeySetterResourceBlocMixin<K extends Object, V> mixin
- Superclass constraints
- Mixin applications
-
Methods
-
add(ResourceEvent event)
→ void
-
Notifies the
Bloc of a new event which triggers
all corresponding EventHandler instances.
If close has already been called, any subsequent calls to add will
be ignored and will not result in any subsequent state changes.
inherited
-
addError(Object error, [StackTrace? stackTrace])
→ void
-
Reports an
error which triggers onError with an optional StackTrace.
inherited
-
applyKey(K callback())
→ void
-
-
close()
→ Future<void>
-
Closes the
event and state Streams.
This method should be called when a Bloc is no longer needed.
Once close is called, events that are added will not be
processed.
In addition, if close is called while events are still being
processed, the Bloc will finish processing the pending events.
inherited
-
emit(ResourceState<K, V> state)
→ void
-
emit should never be used outside of tests.
inherited
-
initialState({required bool isLoading})
→ ResourceState<K, V>
-
inherited
-
listen(void onData(ResourceState<K, V>)?, {Function? onError, void onDone()?, bool? cancelOnError})
→ StreamSubscription<ResourceState<K, V>>
-
Adds a subscription to the
Stream<State>.
Returns a StreamSubscription which handles events from
the Stream<State> using the provided onData, onError and onDone
handlers.
inherited
-
mapEventToState(ResourceEvent event)
→ Stream<ResourceState<K, V>>
-
@Deprecated - Use on
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
on<E extends Event>(EventHandler<E, ResourceState<K, V>> handler, {EventTransformer<E>? transformer})
→ void
-
Register event handler for an event of type
E.
There should only ever be one event handler per event type E.
inherited
-
onAction<A extends ResourceAction>(ActionHandler<A, V> handler, {EventTransformer<A>? transformer, CancelCallback<V>? onCancel})
→ void
-
inherited
-
onChange(Change<ResourceState<K, V>> change)
→ void
-
Called whenever a
change occurs with the given change.
A change occurs when a new state is emitted.
onChange is called before the state of the cubit is updated.
onChange is a great spot to add logging/analytics for a specific cubit.
inherited
-
onError(Object error, StackTrace stackTrace)
→ void
-
Called whenever an
error occurs and notifies BlocObserver.onError.
inherited
-
onEvent(ResourceEvent event)
→ void
-
Called whenever an
event is added to the Bloc.
A great spot to add logging/analytics at the individual Bloc level.
inherited
-
onTransition(Transition<ResourceEvent, ResourceState<K, V>> transition)
→ void
-
Called whenever a
transition occurs with the given transition.
A transition occurs when a new event is added
and a new state is emitted from a corresponding EventHandler.
executed.
onTransition is called before a Bloc's state has been updated.
A great spot to add logging/analytics at the individual Bloc level.
inherited
-
readFreshSource(K key)
→ Stream<V>
-
inherited
-
readTruthSource(K key)
→ Stream<V>
-
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
transformEvents(Stream<ResourceEvent> events, TransitionFunction<ResourceEvent, ResourceState<K, V>> transitionFn)
→ Stream<Transition<ResourceEvent, ResourceState<K, V>>>
-
@Deprecated - Use
on<Event> with an EventTransformer instead.
Will be removed in v8.0.0
inherited
-
transformTransitions(Stream<Transition<ResourceEvent, ResourceState<K, V>>> transitions)
→ Stream<Transition<ResourceEvent, ResourceState<K, V>>>
-
@Deprecated - Override
Stream<State> get stream instead.
Will be removed in v8.0.0
inherited
-
writeTruthSource(K key, V value)
→ FutureOr<void>
-
inherited